@@ -1,19 +1,16 @@
 from binaryai import client, function
+from .error import BinaryAIException
 
 
-def _get_version(default='x.x.x.dev'):
+def _get_version(default='version not found'):
     try:
         from pkg_resources import DistributionNotFound, get_distribution
     except ImportError:
         return default
     else:
         try:
-            return get_distribution(__package__).version
-        except DistributionNotFound:  # Run without install
-            return default
-        except ValueError:  # Python 3 setup
-            return default
-        except TypeError:  # Python 2 setup
+            return get_distribution(__name__).version
+        except DistributionNotFound:
             return default
 
 
@@ -21,13 +18,14 @@ __version__ = _get_version()
 
 __all__ = [
     'client',
-    'function'
+    'function',
+    'BinaryAIException'
 ]
 
 try:
     import idaapi
     from binaryai import ida
-except:
+except ImportError:
     pass
 else:
     __all__.append('ida')
